@@ -32,19 +32,15 @@ class Profile:
     """
 
     def __init__(
-        self, file_paths, parser, q_axis_name="qdcd", theta_axis_name="dcdtheta", pixel_max=1000000, hot_pixel_threshold=200000, transpose=False
+        self, file_paths, parser, q_axis_name="qdcd", theta_axis_name="dcdtheta", pixel_max=10000000, transpose=False
     ):
         self.scans = []
         try:
-            kk = len(pixel_max)
+            is_list = len(pixel_max)
         except TypeError:
             pixel_max = [pixel_max] * len(file_paths)
-        try:
-            jj = len(hot_pixel_threshold)
-        except TypeError:
-            hot_pixel_threshold = [hot_pixel_threshold] * len(file_paths)
         for i, f in enumerate(file_paths):
-            self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max[i], hot_pixel_threshold=hot_pixel_threshold[i], transpose=transpose))
+            self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max[i], transpose=transpose))
         self.q_vectors = None
         self.reflected_intensity = None
 
@@ -220,7 +216,6 @@ class Scan:
         theta_axis_name="dcdtheta",
         energy=None,
         pixel_max=1000000,
-        hot_pixel_threshold=200000,
         transpose=False,
     ):
         self.file_path = file_path
@@ -249,7 +244,6 @@ class Scan:
         self.R = unp.uarray(np.zeros(self.q.size), np.zeros(self.q.size),)
         self.n_pixels = np.zeros(self.q.size)
         self.pixel_max = pixel_max
-        self.hot_pixel_threshold = hot_pixel_threshold
         self.transpose = transpose
 
     def __str__(self):
@@ -330,7 +324,7 @@ class Scan:
                 if self.data['roi1_maxval'][i] > self.pixel_max:
                     to_remove.append(i)
                     continue
-                im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold, transpose=self.transpose)
+                im = image.Image(self.data["file"][i], self.data, self.metadata, transpose=self.transpose)
                 if crop_kwargs is None:
                     im.crop(crop_function)
                 else:
